@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c 10756 2008-03-15 22:45:30Z callum $
+ $Id: battstat_applet.c 11187 2009-01-14 07:55:26Z diegoe $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,8 +39,6 @@
 
 #include <libgnome/libgnome.h>
 
-#include <libgnomeui/libgnomeui.h>
-
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -1176,10 +1174,19 @@ void
 battstat_show_help( ProgressData *battstat, const char *section )
 {
   GError *error = NULL;
+  char *uri;
 
-  gnome_help_display_on_screen( "battstat", section,
-                                gtk_widget_get_screen( battstat->applet ),
-                                &error );
+  if (section)
+    uri = g_strdup_printf ("ghelp:battstat?%s", section);
+  else
+    uri = g_strdup ("ghelp:battstat");
+
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (battstat->applet)),
+                uri,
+                gtk_get_current_event_time (),
+                &error);
+
+  g_free (uri);
 
   if( error )
   {
