@@ -22,22 +22,9 @@
 #include <dirent.h>
 #include <limits.h>
 #include <ctype.h>
-
-#include <gtk/gtkbox.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtkvbox.h>
-
+#include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
-#include <libgnomeui/gnome-help.h>
 #include "geyes.h"
 
 #define NUM_THEME_DIRECTORIES 2
@@ -45,6 +32,12 @@
 
 static char *theme_directories[NUM_THEME_DIRECTORIES];
 
+enum {
+	COL_THEME_DIR = 0,
+	COL_THEME_NAME,
+	TOTAL_COLS
+};
+
 void
 theme_dirs_create (void)
 {
@@ -214,7 +207,7 @@ theme_selected_cb (GtkTreeSelection *selection, gpointer data)
 	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
 		return;
 	
-	gtk_tree_model_get (model, &iter, 0, &theme, -1);
+	gtk_tree_model_get (model, &iter, COL_THEME_DIR, &theme, -1);
 	
 	g_return_if_fail (theme);
 	
@@ -241,9 +234,9 @@ phelp_cb (GtkDialog *dialog)
 {
 	GError *error = NULL;
 
-	gnome_help_display_on_screen (
-		"geyes", "geyes-settings",
-		gtk_window_get_screen (GTK_WINDOW (dialog)),
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+		"ghelp:geyes?geyes-settings",
+		gtk_get_current_event_time (),
 		&error);
 
 	if (error) {
@@ -373,7 +366,7 @@ properties_cb (BonoboUIComponent *uic,
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 
-	model = gtk_list_store_new (1, G_TYPE_STRING);
+	model = gtk_list_store_new (TOTAL_COLS, G_TYPE_STRING, G_TYPE_STRING);
 	tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tree), FALSE);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), tree);
@@ -383,7 +376,7 @@ properties_cb (BonoboUIComponent *uic,
 	
 	cell = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes ("not used", cell,
-                                                           "text", 0, NULL);
+                                                           "text", COL_THEME_NAME, NULL);
         gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
                                                            
         selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (tree));
@@ -401,6 +394,7 @@ properties_cb (BonoboUIComponent *uic,
                         while ((dp = readdir (dfd)) != NULL) {
                                 if (dp->d_name[0] != '.') {
                                         gchar *theme_dir;
+					gchar *theme_name;
 #ifdef PATH_MAX
                                         strcpy (filename, 
                                                 theme_directories[i]);
@@ -408,9 +402,14 @@ properties_cb (BonoboUIComponent *uic,
 #else
 					asprintf (&filename, theme_directories[i], dp->d_name);
 #endif
-                                        gtk_list_store_insert (model, &iter, 0);
-                                        gtk_list_store_set (model, &iter, 0, &filename, -1);
-                                        theme_dir = g_strdup_printf ("%s/", filename);
+					theme_dir = g_strdup_printf ("%s/", filename);
+					theme_name = g_path_get_basename (filename);
+					
+                                        gtk_list_store_append (model, &iter);
+                                        gtk_list_store_set (model, &iter,
+							    COL_THEME_DIR, &filename,
+							    COL_THEME_NAME, theme_name,
+							    -1);
                                         
 					if (!g_ascii_strncasecmp (eyes_applet->theme_dir, theme_dir, strlen (theme_dir))) {
                                         	GtkTreePath *path;
@@ -422,6 +421,7 @@ properties_cb (BonoboUIComponent *uic,
                                                 			  FALSE);
                                                 gtk_tree_path_free (path);
                                         }
+					g_free (theme_name);
                                         g_free (theme_dir);
                                 }
                         }
