@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.17 2005/12/12 00:22:17 philipl Exp $ */
+/* $Id: main.c 11193 2009-01-14 07:56:46Z diegoe $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -12,9 +12,10 @@
 
 #  include <config.h>
 
-#include <gnome.h>
 #include <panel-applet.h>
 
+#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
+
 #include <libgweather/gweather-gconf.h>
 #include <libgweather/gweather-prefs.h>
 
@@ -29,13 +30,16 @@ gweather_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	GWeatherApplet *gw_applet;
 
+	char *prefs_key = panel_applet_get_preferences_key(applet);
+
 	panel_applet_add_preferences(applet, "/schemas/apps/gweather/prefs", NULL);
 	
 	gw_applet = g_new0(GWeatherApplet, 1);   
 	
 	gw_applet->applet = applet;
 	gw_applet->gweather_info = NULL;
-	gw_applet->gconf = gweather_gconf_new(panel_applet_get_preferences_key(applet));
+	gw_applet->gconf = gweather_gconf_new(prefs_key);
+	g_free (prefs_key);
     	gweather_applet_create(gw_applet);
 
     	gweather_prefs_load(&gw_applet->gweather_pref, gw_applet->gconf);
