@@ -28,11 +28,10 @@
 #include <string.h>
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-help.h>
 #include <gio/gio.h>
 #include <panel-applet.h>
-#include <gnome.h>
 
 #include "trash-empty.h"
 #include "xstuff.h"
@@ -365,25 +364,17 @@ trash_applet_open_folder (BonoboUIComponent *component,
                           TrashApplet       *applet,
                           const gchar       *cname)
 {
-  GdkScreen *screen;
-
-  /* Open the "trash:" URI with gnome-open */
-  gchar *argv[] = { "gnome-open", "trash:", NULL };
   GError *err = NULL;
-  gboolean res;
 
-  screen = gtk_widget_get_screen (GTK_WIDGET (applet));
-  res = gdk_spawn_on_screen (screen, NULL,
-                             argv, NULL,
-                             G_SPAWN_SEARCH_PATH,
-                             NULL, NULL,
-                             NULL,
-                             &err);
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+                "trash:",
+                gtk_get_current_event_time (),
+                &err);
 
-  if (!res)
+  if (err)
     {
       error_dialog (applet, _("Error while spawning nautilus:\n%s"),
-                    err->message);
+      err->message);
       g_error_free (err);
     }
 }
@@ -396,10 +387,10 @@ trash_applet_show_help (BonoboUIComponent *component,
   GError *err = NULL;
 
   /* FIXME - Actually, we need a user guide */
-  gnome_help_display_desktop_on_screen (NULL,
-                                        "trashapplet", "trashapplet", NULL,
-                                        gtk_widget_get_screen (GTK_WIDGET (applet)),
-                                        &err);
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+                "ghelp:trashapplet",
+                gtk_get_current_event_time (),
+                &err);
 
   if (err)
     {
@@ -639,22 +630,6 @@ trash_applet_factory (PanelApplet *applet,
 int
 main (int argc, char *argv [])
 {
-  g_thread_init (NULL);
-
-  /* gettext stuff */
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
-  gnome_authentication_manager_init();
-
-  gnome_program_init ("trashapplet", VERSION,
-                      LIBGNOMEUI_MODULE,
-                      argc, argv,
-                      GNOME_CLIENT_PARAM_SM_CONNECT, FALSE,
-                      GNOME_PROGRAM_STANDARD_PROPERTIES,
-                      NULL);
-
   gtk_window_set_default_icon_name ("user-trash");
   g_set_application_name (_("Trash Applet"));
 
